# Random quote generator

[![Workflow for Random quote generator Action](https://github.com/mpita/random-quote-generator/actions/workflows/branch.yaml/badge.svg)](https://github.com/mpita/random-quote-generator/actions/workflows/branch.yml)
[![codecov](https://codecov.io/gh/mpita/random-quote-generator/branch/master/graph/badge.svg?token=9TBVXODWQ0)](https://codecov.io/gh/mpita/random-quote-generator)
[![Documentation Status](https://readthedocs.org/projects/random-quote-generator-py/badge/?version=latest)](https://random-quote-generator-py.readthedocs.io/en/latest/?badge=latest)
[![PyPi page link -- version](https://img.shields.io/pypi/v/random-quote-generator-py.svg)](https://pypi.python.org/pypi/random-quote-generator-py)
